################################################################
#
#   Assembly Line - Digital date display
#
################################################################

from datetime import time
from albow.widget import Widget
from albow.resource import get_font, get_image
from game import game

month_names = [
	"JAN", "FEB", "MAR", "APR", "MAY", "JUN",
	"JUL", "AUG", "SEP", "OCT", "NOV", "DEC"
]

class DigitalDateView(Widget):

	bg_image = get_image("digital_date_bg.png")
	fg_image = get_image("digital_date_fg.png")
	fg_color = (255, 255, 255)
	font = get_font(24, "Vera.ttf")
	digit_width = 16
	month_width = 55
	digit_spacing = 1
	group_spacing = 6
	margin = 7
	yoffset = -1
	
	segment_positions = [
		(7, 16), (1, 16), (6, 55), (6, 16), (1, 16), (1, 16), (1, 16),
		(18, 16), (1, 16), (9, 16), (1, 16), (6, 41)
	]

	def __init__(self):
		Widget.__init__(self, self.bg_image.get_rect())
	
	def draw(self, surf):
		frame = surf.get_rect()
		surf.blit(self.bg_image, (0, 0))
		fg = self.fg_color
		font = self.font
		fg = self.fg_color
		x = 0
		y = frame.centery + self.yoffset
		seg_text = self.segment_text()
		for text, (spacing, width) in zip(seg_text, self.segment_positions):
			x += spacing
			buf = font.render(text, True, fg)
			r = buf.get_rect()
			r.center = (x + width // 2, y)
			surf.blit(buf, r)
			x += width
		fgi = self.fg_image
		r = fgi.get_rect()
		r.center = frame.center
		surf.blit(fgi, r)
	
	def segment_text(self):
		company = game.company
		dt = company.datetime
		day = "%2d" % dt.day
		month = month_names[dt.month - 1]
		year = "%4d" % dt.year
		#h, m = divmod(company.time, 60)
		#t = time(h, m)
		hour = dt.strftime("%I")
		minute = dt.strftime("%M")
		ampm = dt.strftime("%p")
		for c in day:
			yield c
		yield month
		for c in year:
			yield c
		for c in hour:
			yield c
		for c in minute:
			yield c
		yield ampm
