################################################################
#
#   Assembly Line - Drop-down list field
#
################################################################

from pygame.display import get_surface
from albow.controls import ValueView
from albow.dialogs import Modal, Dialog
from albow.palette_view import PaletteView

class DropdownListField(ValueView):

	border_width = 1
	margin = 3
	format = "%s"
	default_width = 100

	def __init__(self, width = None, **kwds):
		ValueView.__init__(self, width = width or self.default_width, **kwds)
	
	def mouse_down(self, e):
		dlog = DropdownListDialog(width = self.width,
			attribute = self.attribute, model = self.model,
			bg_color = self.inherited('bg_color'),
			client = self)
		p = self.local_to_global((0, 0))
		dlog.topleft = p
		sw, sh = get_surface().get_size()
		if dlog.bottom > sh:
			dlog.bottom = sh
		if dlog.top < 0:
			dlog.top = 0
		dlog.present(centered = False)

#-----------------------------------------------------------------------

class DropdownListDialog(Dialog):

	margin = 0
	click_outside_response = False

	def __init__(self, **kwds):
		Dialog.__init__(self, DropdownSelector(**kwds))

#-----------------------------------------------------------------------

class DropdownSelector(PaletteView):

	border_width = 1
	lmargin = 5
	#highlight_style = 'fill'
	fg_color = (0, 0, 0)
	bg_color = (255, 255, 255)
	sel_color = (62, 188, 254)
	attribute = None
	model = None
	client = None

	def __init__(self, width = 150, height = 300, **kwds):
		font = self.predict_font(kwds)
		cw = width
		ch = font.get_linesize() + 4
		nr = height // ch
		PaletteView.__init__(self, (cw, ch), nr, 1, scrolling = True, **kwds)
		self.scroll_to_value(self.get_value())
	
	def __getattr__(self, name):
		return getattr(self.client, name)
	
	def item_is_selected(self, n):
		return self.value_for_item_no(n) == self.get_value()
	
	def scroll_to_value(self, value):
		n = self.client.item_no_for_value(value)
		self.scroll_to_item(n or 0)
	
	def click_item(self, n, e):
		value = self.value_for_item_no(n)
		self.client.set_value(value)
		self.dismiss(True)
	
	def draw_item(self, surf, n, rect):
		client = self.client
		value = client.value_for_item_no(n)
		text = client.format_value(value)
		buf = self.font.render(text, True, self.fg_color)
		r = buf.get_rect()
		r.midleft = rect.left + self.lmargin, rect.centery
		surf.blit(buf, r)
