################################################################
#
#   Assembly Line - Conveyor belt section
#
################################################################

from pygame import Rect
from albow.resource import get_image
from albow.image_array import get_image_array
from machine import Machine

class ConveyorBase(object):
	#  drive   Machine

	is_conveyor = True
	layer = 0
	rotation_mask = 1
	num_frames = 8
	speed = 4

	drive = None
	
	def get_phase(self):
		drive = self.drive
		if drive:
			return drive.phase % self.num_frames
		else:
			return 0

	def forward_direction(self):
		return self.global_vector((1, 0))
	
	def handle_part(self, factory, part):
		v = self.global_transport_vector()
		if v:
			factory.move_part(part, v)
		return True
	
	def global_transport_vector(self):
		drive = self.drive
		if drive and drive.running:
			return self.global_vector((self.speed * drive.direction, 0))


class Conveyor(ConveyorBase, Machine):

	title = "Conveyor Section"
	icon = get_image("conveyor_icon.png")
	cost = 100

	orgx, orgy = -16, -16
	
	local_bounding_rect = Rect(orgx, orgy, 32, 64)

	local_covered_rects = [
		[local_bounding_rect],
		[]
	]

	images = [
		get_image_array("conveyor_h.png", ConveyorBase.num_frames),
		get_image_array("conveyor_v.png", ConveyorBase.num_frames),
	]
	
	def draw_local(self, surf, t):
		org = self.local_topleft()
		#images = self.images[self.rotation & 1]
		#image = images[self.get_phase()]
		#t.draw_image(surf, image, org, debug = True)
		t.draw_image(surf, self.images, org, self.get_phase())

	def update_neighbourhood(self, factory):
		for d in (-32, 32):
			p = self.global_point((d, 0))
			m = factory.machine_at(p, 0)
			if m and m.is_conveyor_end:
				m.next_to_conveyor(d)
