################################################################
#
#   Assembly Line - Conveyor end
#
################################################################

from pygame import Rect
from albow.resource import get_image
from albow.image_array import get_image_array
from machine import Machine
from conveyor import ConveyorBase

class ConveyorEnd(ConveyorBase, Machine):

	title = "Conveyor End"
	icon = get_image("conveyor_end_icon.png")
	cost = 150
	is_conveyor_end = True

	orgx, orgy = -16, -16
	
	local_bounding_rect = Rect(orgx, orgy, 32, 64)

	local_covered_rects = [
		[local_bounding_rect],
		[]
	]

	images = [
		get_image_array("conveyor_end_l.png", ConveyorBase.num_frames),
		get_image_array("conveyor_end_t.png", ConveyorBase.num_frames),
	], [
		get_image_array("conveyor_end_r.png", ConveyorBase.num_frames),
		get_image_array("conveyor_end_b.png", ConveyorBase.num_frames),
	]
	
	which_end = 0 # 0 = left/top, 1 = right/bottom
	
	def draw_local(self, surf, t):
		org = self.local_topleft()
		t.draw_image(surf, self.images[self.which_end], org, self.get_phase())

	def next_to_conveyor(self, d):
		self.which_end = d > 0

	def update_neighbourhood(self, factory):
		for d in (-32, 32):
			p = self.global_point((d, 0))
			m = factory.machine_at(p, 0)
			if m and m.is_conveyor:
				self.next_to_conveyor(-d)
