################################################################
#
#   Assembly Line - Y Offset mixin
#
################################################################

from albow.controls import IntEditor

#------------------------------------------------------------------------

class YOffset(object):
	#  Mixin for machines having a Y Offset parameter.
	#
	#  yoffset    int
	#
	#  Abstract methods:
	#
	#    yoffset_restriction() -> int
	#
	#      Return height of entity whose Y offset is being set.

	yoffset = 0

	def get_yoffset(self):
		return self.yoffset
	
	def set_yoffset(self, y):
		self.yoffset = y
		self.limit_yoffset()
	
	_yoffset = property(get_yoffset, set_yoffset)
	
	def limit_yoffset(self):
		h = self.yoffset_restriction()
		if h is not None:
			ymin = -30 + h // 2
			ymax = 30 - (h + 1) // 2
			y = self.yoffset
			y = max(ymin, min(ymax, y))
			self.yoffset = y
	
#------------------------------------------------------------------------

def YOffsetField(machine):
	return IntEditor(min = -30, max = 30, empty = None,
		attribute = '_yoffset', model = machine)
