################################################################
#
#   Assembly Line - Product-related view classes
#
################################################################

import textwrap
from pygame import Rect
from albow.widget import Widget
from albow.controls import Label, Row, Column, ValueView
from albow.resource import get_font
from material import draw_formula
from part_view import PartInfoView, PixelsView
from material_view import ProductMaterialView
from game import game

#----------------------------------------------------------------------------

class ProductTableBase(object):
	#  Mixin class for TableViews that show a list of developed products.
	
	selectable = False

	def num_rows(self):
		return game.company.num_developed_products()
	
	def row_is_selected(self, n):
		if self.selectable:
			p = self.product_no(n)
			return game.product_is_selected(p)
	
	def click_row(self, n, e):
		if self.selectable:
			p = game.company.developed_product_no(n)
			game.select_product(p)
		
	def product_no(self, n):
		return game.company.developed_product_no(n)
	
	def product_and_history_no(self, n):
		product = self.product_no(n)
		history = game.company.find_product_history(product)
		return product, history

#----------------------------------------------------------------------------

class ProductPaletteBase(ProductTableBase):
	#  Mixin class for PaletteViews that show a list of developed products.

	def num_items(self):
		return self.num_rows()
	
	def item_is_selected(self, n):
		return self.row_is_selected(n)
	
	def click_item(self, n, e):
		self.click_row(n, e)

#----------------------------------------------------------------------------

class ProductView(Widget):

	def __init__(self, height, pixel_size, get_product, **kwds):
		Widget.__init__(self, **kwds)
		self.get_product = get_product
		pixels_view = PixelsView(pixel_size, self.get_part)
		info_view = PartInfoView(pixels_view.width, self.get_part)
		desc_view = DescView(get_product)
		material_view = ProductMaterialView(height, get_product)
		desc_view.width = pixels_view.width
		on_left = Column([desc_view, info_view, pixels_view], align = 'l')
		on_right = Column([Label("Materials"), material_view], align = 'l')
		self.add(Row([on_left, on_right], align = 't'))
		self.shrink_wrap()
	
	def get_part(self):
		product = self.get_product()
		if product:
			return product.part

#----------------------------------------------------------------------------

class DescView(Label):

	font = get_font(12, "Vera.ttf")

	def __init__(self, get_product):
		Label.__init__(self, "", width = 400)
		self.height = 30
		self.get_product = get_product
	
	def get_text(self):
		product = self.get_product()
		if product:
			text = product.description
			return textwrap.fill(text, 80)
		else:
			return ""
	
	def set_text(self, x):
		pass

	text = property(get_text, set_text)

