################################################################
#
#   Assembly Line - Products page
#
################################################################

from albow.controls import Label, Row, Column
from albow.palette_view import PaletteView
from screen import ALScreen
from product_view import ProductView, ProductPaletteBase
from game import game

class ProductsPage(ALScreen):

	#bg_color = (255, 244, 155)
	bg_color = (208, 153, 15)
	fg_color = (0, 0, 0)

	def __init__(self, shell):
		ALScreen.__init__(self, shell)
		height = self.height - 24
		list_view = ProductListView(self.game, height - 32)
		product_view = ProductView(list_view.height,
			pixel_size = 8,
			get_product = self.get_product,
			get_visible = self.product_selected)
		contents = Row([list_view, product_view], align = 't')
		contents.topleft = (16, 16)
		self.add(contents)
	
	def product_selected(self):
		return self.get_product() is not None
	
	def get_product(self):
		product = game.selected_product
		if game.company.product_is_developed(product):
			return product


class ProductListView(ProductPaletteBase, PaletteView):

	cell_width = 150
	lmargin = 5
	#highlight_style = 'fill'
	fg_color = (0, 0, 0)
	bg_color = (224, 224, 224)
	sel_color = (62, 188, 254)
	border_width = 1
	
	selectable = True

	def __init__(self, game, height):
		self.game = game
		cw = self.cell_width
		ch = self.font.get_linesize() + 4
		nr = height // ch
		PaletteView.__init__(self, (cw, ch), nr, 1, scrolling = True)
	
	def draw_item(self, surf, n, rect):
		#product = self.game.products[n]
		product = self.product_no(n)
		buf = self.font.render(product.title, True, self.fg_color)
		r = buf.get_rect()
		r.midleft = rect.left + self.lmargin, rect.centery
		surf.blit(buf, r)
