################################################################
#
#   Assembly Line - Sales report
#
################################################################

from __future__ import division
from report import ReportTableView, TC
from game import game
from format import format_dollars
from product_view import ProductTableBase

class SalesReport(ProductTableBase, ReportTableView):

	title = "Product Sales"

	columns = [
		TC("Product",       130, 'l'),
		TC("Sold",           50, 'r'),
		TC("Missed",         55, 'r'),
		TC("%",              40, 'r', "%.1f"),
		TC("Lost",           40, 'r'),
		TC("%",              40, 'r', "%.1f"),
		TC("Scrapped",       90, 'r'),
		TC("Freight",        60, 'r', format_dollars),
		TC("Revenue",        70, 'r', format_dollars),
		TC("Sat",            45, 'r'),
		TC("Dis",            45, 'r'),
		TC("% Sat",          50, 'r', "%.1f"),
	]
	
	def row_data(self, n):
		product = self.product_no(n)
		h = game.company.find_product_history(product)
		sel = self.selections
		if sel.kind == 'total':
			s = h.total
		else:
			p, n = sel.period_range()
			s = h.stats_for_periods(p, n)
		sold = s.number_sold
		missed = s.sales_missed
		lost = s.sales_lost
		if sold:
			num_missed = missed
			num_lost = lost
			pc_missed = 100 * missed / (sold + missed)
			pc_lost = 100 * lost / (sold + missed + lost)
		else:
			num_missed = None
			num_lost = None
			pc_missed = None
			pc_lost = None
		rep = h.reputation_ratio()
		if rep is not None:
			rep *= 100
		return (
			product.title,
			sold,
			num_missed,
			pc_missed,
			num_lost,
			pc_lost,
			s.number_trashed,
			s.freight_cost,
			s.revenue,
			s.satisfied_customers,
			s.dissatisfied_customers,
			s.percent_satisfied,
		)
